from typing import *
from starlette.requests import Request
from starlette.responses import *
from royalnet.constellation import *
import logging


log = logging.getLogger(__name__)


class ApiDiscordPlayStar(PageStar):
    path = "/api/discord/play"

    async def page(self, request: Request) -> JSONResponse:
        url = request.query_params.get("url", "")
        user = request.query_params.get("user")
        try:
            guild_id: Optional[int] = int(request.query_params.get("guild_id", None))
        except (ValueError, TypeError):
            guild_id = None
        log.info(f"Received request to play {url} on guild_id {guild_id} via web")
        response = await self.interface.call_herald_event("discord", "discord_play",
                                                          url=url,
                                                          guild_id=guild_id,
                                                          user=user)
        return JSONResponse(response, headers={
            "Access-Control-Allow-Origin": "*",
        })



from starlette.requests import Request
from starlette.responses import *
from royalnet.constellation import *
from royalnet.utils import *
from ..tables import *
import uuid


class ApiWikiGetStar(PageStar):
    path = "/api/wiki/get/{wiki_page_uuid}"

    async def page(self, request: Request) -> JSONResponse:
        wiki_page_uuid_str = request.path_params.get("wiki_page_uuid", "")
        try:
            wiki_page_uuid = uuid.UUID(wiki_page_uuid_str)
        except (ValueError, AttributeError, TypeError):
            return shoot(400, "Invalid wiki_page_uuid")
        async with self.alchemy.session_acm() as session:
            wikipage: WikiPage = await asyncify(session.query(self.alchemy.get(WikiPage)).get, wiki_page_uuid)
            if wikipage is None:
                return shoot(404, "No such page")
            return JSONResponse(wikipage.json_full())



from .mmchoice import MMChoice
from .mminterfacedata import MMInterfaceData, MMInterfaceDataTelegram
from .leaguetier import LeagueTier
from .leaguerank import LeagueRank
from .leagueleague import LeagueLeague
from .royalqueue import RoyalQueue
from .dotamedal import DotaMedal
from .dotastars import DotaStars
from .dotarank import DotaRank

__all__ = [
    "MMChoice",
    "MMInterfaceData",
    "MMInterfaceDataTelegram",
    "LeagueTier",
    "LeagueRank",
    "LeagueLeague",
    "RoyalQueue",
    "DotaMedal",
    "DotaStars",
    "DotaRank",
]
